# -*- coding: utf-8 -*-
from django.contrib import admin
from django.utils.translation import ugettext as _

from jmb.jadmin import JumboModelAdmin

from .models import WebRequest


class WebRequestAdmin(JumboModelAdmin):
    fieldsets = (
        (_('logs admin'), {
            'fields': (
                'date_create', 'date_last_modify',
            ),
            'classes': ('collapse',)
        }),
        (None, {
            'fields': (
                'is_ajax',
                ('user_id', 'user_email'),
                ('cookie_code', 'session_id'),
                'method',
                'response_code',
                'path',
                'ip',
                'referer',
                'user_agent',
                'language',
            ),
        }),
    )
    list_display = (
        'get_edit_icon', 'is_ajax', 'date_create', 'path', 'method',
        'response_code', 'user_id', 'user_email', 'cookie_code'
    )
    readonly_fields = (
        'is_ajax',
        'user_id',
        'user_email',
        'cookie_code',
        'session_id',
        'method',
        'response_code',
        'path',
        'ip',
        'referer',
        'user_agent',
        'language',
    )
    search_fields = ('path', 'response_code', 'method')
    advanced_search_fields = (
        ('is_ajax',),
        ('date_create__gte', 'date_create__lte'),
        ('method__in', 'response_code__in'),
        ('user_id', 'user_email__icontains'),
        ('path__icontains',),
        ('referer__icontains',),
        ('user_agent__icontains',),
        ('language',),
        ('cookie_code__icontains',),
    )
    actions = None

    def has_delete_permission(self, request, obj=None):
        return False

    def has_add_permission(self, request):
        return False

admin.site.register(WebRequest, WebRequestAdmin)
