# coding: utf-8
import datetime

from django.conf import settings

from .models import WebRequest
from .utils import patterns, gen_cookie_code


class AnalyticsMiddleware(object):

    def process_response(self, request, response):
        if request.method.lower() in settings.JMB_ANALYTICS_IGNORE_METHOD_NAMES:
            return response

        if response.status_code < 400 and settings.JMB_ANALYTICS_ONLY_ERRORS:
            return response

        ignore_patterns = patterns(False, *settings.JMB_ANALYTICS_IGNORE_PATHS)
        if ignore_patterns.resolve(request.path[1:]):
            return response

        if request.is_ajax() and settings.JMB_ANALYTICS_IGNORE_AJAX:
            return response

        if request.META.get('REMOTE_ADDR') in settings.JMB_ANALYTICS_IGNORE_IP:
            return response

        ignore = patterns(False, *settings.JMB_ANALYTICS_IGNORE_USER_AGENTS)
        if ignore.resolve(request.META.get('HTTP_USER_AGENT', '')):
            return response

        if getattr(request, 'user', False):
            if hasattr(request.user, 'username') and request.user.username in settings.JMB_ANALYTICS_IGNORE_USERNAME:
                return response

        if '_jmb_a' not in request.COOKIES:
            max_age = 24 * 60 * 60
            expires = datetime.datetime.strftime(
                datetime.datetime.utcnow() + datetime.timedelta(seconds=max_age),
                "%a, %d-%b-%Y %H:%M:%S GMT"
            )
            cookie_code = gen_cookie_code()
            response.set_cookie('_jmb_a', cookie_code, max_age=max_age, expires=expires)
        else:
            cookie_code = request.COOKIES.get('_jmb_a')

        r = WebRequest()
        r.from_http_request(request, response, cookie_code=cookie_code)
        return response
