# coding: utf-8

from django.conf import settings
from django.db import models
from django.utils.translation import ugettext as _

from jmb.analytics import utils

from jmb.core.db import DateModel


class WebRequest(DateModel):
    user_id = models.IntegerField(
        blank=True, null=True,
        db_index=True,
        verbose_name=_('user id')
    )
    user_email = models.CharField(
        blank=True,
        max_length=255,
        db_index=True,
        verbose_name=_('user email')
    )
    cookie_code = models.CharField(
        max_length=255,
        verbose_name=_('cookie code'),
        blank=True, null=True
    )
    session_id = models.CharField(
        max_length=255,
        verbose_name=_('session id'),
        blank=True, null=True
    )
    method = models.CharField(
        max_length=10,
        choices=settings.JMB_ANALYTICS_WEBREQUEST_METHOD_CHOICES,
        verbose_name=_('method')
    )
    response_code = models.IntegerField(
        choices=settings.JMB_ANALYTICS_WEBREQUEST_RESPONSE_CODE_CHOICES,
        verbose_name=_('response code'),
    )
    path = models.TextField(
        verbose_name=_('path'),
    )
    is_ajax = models.BooleanField(
        default=False,
        verbose_name=_('is ajax')
    )
    ip = models.GenericIPAddressField(
        verbose_name=_('ip address')
    )
    referer = models.TextField(
        verbose_name=_('referer'),
        blank=True, null=True
    )
    user_agent = models.CharField(
        max_length=255,
        verbose_name=_('user agent'),
        blank=True, null=True
    )
    language = models.CharField(
        max_length=255,
        verbose_name=_('language'),
        blank=True, null=True
    )

    class Meta:
        verbose_name = _('web request')
        verbose_name_plural = _('web requests')
        ordering = ('-date_create',)

    def __unicode__(self):
        return u'{}: {} {} - {}'.format(
            self.date_create, self.get_method_display(),
            self.path, self.get_response_code_display()
        )

    def from_http_request(self, request, response=None, cookie_code=None):
        self.method = request.method.lower()
        self.path = request.build_absolute_uri()
        self.is_ajax = request.is_ajax()
        self.ip = request.META.get('REMOTE_ADDR', '')
        self.referer = request.META.get('HTTP_REFERER', '')
        self.user_agent = request.META.get('HTTP_USER_AGENT', '')[:255]
        self.language = request.META.get('HTTP_ACCEPT_LANGUAGE', '')[:255]
        self.session_id = request.session.session_key if hasattr(request, 'session') else None
        self.cookie_code = cookie_code

        if getattr(request, 'user', False):
            if request.user.is_authenticated():
                self.user_id = request.user.id
                self.user_email = request.user.email

        if response:
            self.response_code = response.status_code
            # if (response.status_code == 301) or (response.status_code == 302):
            #     self.redirect = response['Location']

        self.save()
